generate_anki_df: Generate a dataframe for anki cards

Description Usage Arguments Value Examples

View source: R/parserd.R

Description

This generates a dataframe of anki cards. The front of the card is the function name, the back is the title, description, and examples. Note that you need to have the package installed for this to work.

Usage

1

Arguments

pkg

The package whose functions you want to memorize

Value

A dataframe

Examples

1

GShotwell/ankify documentation built on May 28, 2019, 8:58 p.m.