write_anki_df: Write an anki csv

Description Usage Arguments Value Examples

View source: R/parserd.R

Description

This writes an anki csv which can then be imported into the anki app

Usage

1
write_anki_df(pkg, path)

Arguments

pkg

The name of the package whose functions you would like to memorize

path

Path for the exported csv

Value

Nothing, called for its side effects.

Examples

1
write_anki_df("purrr", "purrr.csv")

GShotwell/ankify documentation built on May 28, 2019, 8:58 p.m.