Description Usage Arguments Value Examples
This generates a dataframe of anki cards. The front of the card is the function name, the back is the title, description, and examples. Note that you need to have the package installed for this to work.
1 | generate_anki_df(pkg)
|
pkg |
The package whose functions you want to memorize |
A dataframe
1 | generate_anki_df("purrr")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.