Description Usage Arguments Value Examples
This writes an anki csv which can then be imported into the anki app
1 | write_anki_df(pkg, path)
|
pkg |
The name of the package whose functions you would like to memorize |
path |
Path for the exported csv |
Nothing, called for its side effects.
1 | write_anki_df("purrr", "purrr.csv")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.